<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AppItemMenu</name>
    <message>
        <source>Open</source>
        <translation>Aç</translation>
    </message>
    <message>
        <source>Pin to Top</source>
        <translation>Üste Sabitle</translation>
    </message>
    <message>
        <source>Move to Top</source>
        <translation>Üste Taşı</translation>
    </message>
    <message>
        <source>Remove from favorites</source>
        <translation>Favorilerden kaldır</translation>
    </message>
    <message>
        <source>Add to favorites</source>
        <translation>Favorilere ekle</translation>
    </message>
    <message>
        <source>Remove from desktop</source>
        <translation>Masaüstünden kaldır</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Masaüstüne gönder</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Rıhtım&apos;dan kaldır</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Rıhtıma gönder</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Başlangıçtan kaldır</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Başlangıca ekle</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation>Vekil sunucu kullan</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Ekran ölçeklendirmeyi devre dışı bırak</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Kaldır</translation>
    </message>
</context>
<context>
    <name>BottomBar</name>
    <message>
        <source>Power</source>
        <translation>Güç</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Ara</translation>
    </message>
    <message>
        <source>Full-screen Mode</source>
        <translation>Tam Ekran Kipi</translation>
    </message>
</context>
<context>
    <name>DummyAppItemMenu</name>
    <message>
        <source>Install</source>
        <translation>Kur</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Kaldır</translation>
    </message>
</context>
<context>
    <name>FrequentlyUsedView</name>
    <message>
        <source>Frequently Used</source>
        <translation>Sık kullanılır</translation>
    </message>
</context>
<context>
    <name>FullscreenFrame</name>
    <message>
        <source>Window Mode</source>
        <translation>Pencere Kipi</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Internet</source>
        <translation>İnternet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Sohbet</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Oyunlar</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofis</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Okuma</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Geliştirme</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Diğerleri</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>&quot;%1&quot; öğesini kaldırmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
<context>
    <name>RecentlyInstalledView</name>
    <message>
        <source>Recently Installed</source>
        <translation>Son zamanlarda yüklenen</translation>
    </message>
</context>
<context>
    <name>SearchResultView</name>
    <message>
        <source>All Apps</source>
        <translation>Tüm Uygulamalar</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>Hiçbir arama sonucu bulunamadı</translation>
    </message>
</context>
<context>
    <name>SideBar</name>
    <message>
        <source>Free sorting</source>
        <translation>Serbest sıralama</translation>
    </message>
    <message>
        <source>Sort by category</source>
        <translation>Kategoriye göre sırala</translation>
    </message>
    <message>
        <source>Sort by name</source>
        <translation>İsmime göre sırala</translation>
    </message>
    <message>
        <source>Sorting Mode</source>
        <translation>Sıralama Kipi</translation>
    </message>
    <message>
        <source>Computer</source>
        <translation>Bilgisayar</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Resimler</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Belgeler</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Masaüstü</translation>
    </message>
    <message>
        <source>Control Center</source>
        <translation>Kontrol Merkezi</translation>
    </message>
</context>
<context>
    <name>launcheritem</name>
    <message>
        <source>Internet</source>
        <translation>İnternet</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Sohbet</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Müzik</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Video</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Grafik</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Oyunlar</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Ofis</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Okuma</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Geliştirme</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Sistem</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Diğerleri</translation>
    </message>
    <message>
        <source>launchpad</source>
        <translation>başlatma</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall &quot;%1&quot;?</source>
        <translation>&quot;%1&quot; öğesini kaldırmak istediğinizden emin misiniz?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
</context>
</TS>